#!/bin/bash

mode=""
ip=""
timeout=3600

function showUsage {
  echo "Usage: $(basename $0) [-adh] [-t TIMEOUT] <ip>"
  echo "Add or remove IP in radmin allowed IP"
  echo "  -h          Show this help"
  echo "  -a          Add ip"
  echo "  -d          Delete ip"
  echo "  -t TIMEOUT  Timeout in seconds before removing this IP (default: 3600 seconds)"
  echo "Example: $(basename $0) -a -t 3600 1.2.3.4"
  exit 1
}

function addIP {
  ipset -exist add radmin $ip timeout $timeout
  echo "Added $ip with timeout $timeout"
  exit $?
}

function deleteIP {
  ipset -exist del radmin $ip
  echo "Removed $ip"
  exit 0
}


optstring=":adht"
while getopts ${optstring} arg; do
  case ${arg} in
    h)
      showUsage
      ;;
    a)
      mode="add"
      ;;
    d) 
      mode="del"
      ;;
    t)
      timeout="${OPTARG}"
      ;;
    :)
      echo "$0: Must supply an argument to -$OPTARG." >&2
      exit 1
      ;;
    ?)
      echo "Invalid option: -${OPTARG}."
      exit 2
      ;;
  esac
done
shift $((OPTIND-1))
ip=$@


if [ "$ip" == "" ]
then
  echo "IP not set"
  showUsage
fi

if [ "$mode" == "add" ]
then
  addIP
  exit 0
fi
if [ "$mode" == "del" ]
then
  deleteIP
  exit 0
fi

echo "Noting to do"
exit 1